/*
 * Copyright (C) 2018-2021 QuasarApp.
 * Distributed under the lgplv3 software license, see the accompanying
 * Everyone is permitted to copy and distribute verbatim copies
 * of this license document, but changing it is not allowed.
*/


#ifndef LOCALES_H
#define LOCALES_H

#include "quasarapp_global.h"

#include <QLocale>
#include <QString>

class QCoreApplication;
class QTranslator;

namespace QuasarAppUtils {

/**
 * @brief The Locales class for parese local files
 */
class QUASARAPPSHARED_EXPORT Locales : public QObject
{
    Q_OBJECT
public:

    /**
     * @brief setLocale This method sets locale for application and loaded all translations for this locale.
     * @param locale This is new locale.
     * @param location This is localtion of the qm file. if you want to load files from resource set patht to resources files
     *  Example :(:/tr/)
     * @return true if the all ltranstations files loaded successful.
     */
    static bool setLocale(const QLocale &locale);

    /**
     * @brief translate init translation of applictaion
     * @param locale - see info about QLocale
     * @param location - path to folder with qm files. example (:/tr)
     * @return return true if locale set for application
     */
    bool translate(const QLocale &locale = QLocale::system(),
                   QString location = "");

    /**
     * @brief instance
     * @return return static object
     */
    static Locales *instance();

signals:
    /**
     * @brief sigTranslationChanged - emited when set new locale for application.
     */
    void sigTranslationChanged();

private:
    Locales() = default;
    bool setLocalePrivate(const QLocale &locale = QLocale::system());


    /**
     * @brief getTranslator
     * @return instance of Translation
     */
    static QTranslator* getTranslator();
    QString _location;

};
}


#endif // LOCALES_H
